==> lokalise_flutter_sdk-0.5.0.tar.gz: test/otav2/data/repositories/remote_bundle_repository_test.dart <==
import 'dart:io';

import 'package:archive/archive_io.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:lokalise_flutter_sdk/otav2/data/api/ota_api.dart';
import 'package:lokalise_flutter_sdk/otav2/data/api/responses/bundle_response.dart';
import 'package:lokalise_flutter_sdk/otav2/data/repositories/remote_bundle_repository.dart';
import 'package:lokalise_flutter_sdk/otav2/domain/dto/get_remote_bundle_dto.dart';
import 'package:lokalise_flutter_sdk/otav2/domain/exceptions/internal_exception.dart';
import 'package:lokalise_flutter_sdk/otav2/domain/models/credentials.dart';
import 'package:mockito/annotations.dart';
import 'package:mockito/mockito.dart';

import 'remote_bundle_repository_test.mocks.dart';

@GenerateMocks([OtaApi])
void main() {
  final credentials = Credentials(projectId: 'test-id', token: 'test-token');

  late RemoteBundleRepository remoteRepo;
  late MockOtaApi otaApiMock;

  setUp(() {
    otaApiMock = MockOtaApi();
    remoteRepo = RemoteBundleRepository(otaApi: otaApiMock);
  });

  group('RemoteTranslationRepository - getBundle', () {
    test('rethrow internal exception', () {
      // Given
      when(
        otaApiMock.getBundle(
          credentials: credentials,
          request: anyNamed('request'),
        ),
      ).thenThrow(InternalException.unexpected(param: 'test'));

      // When - Then
      final dto = GetRemoteBundleDto(
        credentials: credentials,
        appVersion: '1',
        translationVersion: 1,
        preRelease: true,
      );
      expect(
        remoteRepo.getBundle(
          getRemoteBundleDto: dto,
        ),
        throwsA(isA<InternalException>()),
      );
    });

    test('returns null', () async {
      // Given
      when(
        otaApiMock.getBundle(
          credentials: credentials,
          request: anyNamed('request'),
        ),
      ).thenAnswer((_) => Future.value(null));

      // When
      final dto = GetRemoteBundleDto(
        credentials: credentials,
        appVersion: '1',
        translationVersion: 1,
        preRelease: true,
      );
      final result = await remoteRepo.getBundle(
        getRemoteBundleDto: dto,
      );

      // Then
      expect(result.projectId, equals(credentials.projectId));
      expect(result.appVersion, equals(dto.appVersion));
      expect(result.translationVersion, equals(dto.translationVersion));
      expect(result.languageBundles, isEmpty);
    });

    test('empty bundle', () async {
      // Given
      final mockResponse = BundleResponse(bundle: Archive(), version: 15);
      when(
        otaApiMock.getBundle(
          credentials: credentials,
          request: anyNamed('request'),
        ),
      ).thenAnswer((_) => Future.value(mockResponse));

      // When
      InternalException? exception;
      try {
        final dto = GetRemoteBundleDto(
          credentials: credentials,
          appVersion: '1',
          translationVersion: 1,
          preRelease: true,
        );
        await remoteRepo.getBundle(
          getRemoteBundleDto: dto,
        );
      } on InternalException catch (e) {
        exception = e;
      }

      // Then
      expect(exception, isNotNull);
      expect(exception!.code, equals(InternalException.bundleEmptyError));
    });

    test('wrong bundle format', () async {
      // Given
      final zipFile = File('test/assets/bundle-wrong_format.zip');
      final mockResponse = BundleResponse(
        bundle: ZipDecoder().decodeBytes(zipFile.readAsBytesSync()),
        version: 15,
      );
      when(
        otaApiMock.getBundle(
          credentials: credentials,
          request: anyNamed('request'),
        ),
      ).thenAnswer((_) => Future.value(mockResponse));

      // When
      InternalException? exception;
      try {
        final dto = GetRemoteBundleDto(
          credentials: credentials,
          appVersion: '1',
          translationVersion: 1,
          preRelease: true,
        );
        await remoteRepo.getBundle(
          getRemoteBundleDto: dto,
        );
      } on InternalException catch (e) {
        exception = e;
      }

      // Then
      expect(exception, isNotNull);
      expect(exception!.code, equals(InternalException.bundleFormatError));
    });

    test('success', () async {
      // Given
      final zipFile = File('test/assets/bundle-correct.zip');
      final mockResponse = BundleResponse(
        bundle: ZipDecoder().decodeBytes(zipFile.readAsBytesSync()),
        version: 15,
      );
      when(
        otaApiMock.getBundle(
          credentials: credentials,
          request: anyNamed('request'),
        ),
      ).thenAnswer((_) => Future.value(mockResponse));

      // When
      final dto = GetRemoteBundleDto(
        credentials: credentials,
        appVersion: '1',
        translationVersion: 1,
        preRelease: true,
      );
      final result = await remoteRepo.getBundle(
        getRemoteBundleDto: dto,
      );

      // Then
      expect(result.projectId, equals(credentials.projectId));
      expect(result.appVersion, equals(dto.appVersion));
      expect(result.translationVersion, equals(mockResponse.version));
      expect(result.languageBundles.length, equals(3));

      for (final element in result.languageBundles) {
        expect(element.translations.length, equals(1));

        String value = '';
        switch (element.locale) {
          case 'en':
            value = 'hello world';
            break;
          case 'es':
            value = 'hola mundo';
            break;
          case 'lv':
            value = 'sveika pasaule';
            break;
          default:
            throw Exception('Unexpected locale: ${element.locale}');
        }

        expect(
          element.translations['hello_world']!.getTranslation({}),
          equals(value),
        );
      }
    });
  });
}

==> lokalise_flutter_sdk-0.5.1.tar.gz: test/otav2/data/repositories/remote_bundle_repository_test.dart <==
import 'dart:io';

import 'package:archive/archive_io.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:lokalise_flutter_sdk/otav2/data/api/ota_api.dart';
import 'package:lokalise_flutter_sdk/otav2/data/api/responses/bundle_response.dart';
import 'package:lokalise_flutter_sdk/otav2/data/repositories/remote_bundle_repository.dart';
import 'package:lokalise_flutter_sdk/otav2/domain/dto/get_remote_bundle_dto.dart';
import 'package:lokalise_flutter_sdk/otav2/domain/exceptions/internal_exception.dart';
import 'package:lokalise_flutter_sdk/otav2/domain/models/credentials.dart';
import 'package:mockito/annotations.dart';
import 'package:mockito/mockito.dart';

import 'remote_bundle_repository_test.mocks.dart';

@GenerateMocks([OtaApi])
void main() {
  final credentials = Credentials(projectId: 'test-id', token: 'test-token');

  late RemoteBundleRepository remoteRepo;
  late MockOtaApi otaApiMock;

  setUp(() {
    otaApiMock = MockOtaApi();
    remoteRepo = RemoteBundleRepository(otaApi: otaApiMock);
  });

  group('RemoteTranslationRepository - getBundle', () {
    test('rethrow internal exception', () {
      // Given
      when(
        otaApiMock.getBundle(
          credentials: credentials,
          request: anyNamed('request'),
        ),
      ).thenThrow(InternalException.unexpected(param: 'test'));

      // When - Then
      final dto = GetRemoteBundleDto(
        credentials: credentials,
        appVersion: '1',
        translationVersion: 1,
        preRelease: true,
      );
      expect(
        remoteRepo.getBundle(
          getRemoteBundleDto: dto,
        ),
        throwsA(isA<InternalException>()),
      );
    });

    test('returns null', () async {
      // Given
      when(
        otaApiMock.getBundle(
          credentials: credentials,
          request: anyNamed('request'),
        ),
      ).thenAnswer((_) => Future.value(null));

      // When
      final dto = GetRemoteBundleDto(
        credentials: credentials,
        appVersion: '1',
        translationVersion: 1,
        preRelease: true,
      );
      final result = await remoteRepo.getBundle(
        getRemoteBundleDto: dto,
      );

      // Then
      expect(result, isNull);
    });

    test('empty bundle', () async {
      // Given
      final mockResponse = BundleResponse(bundle: Archive(), version: 15);
      when(
        otaApiMock.getBundle(
          credentials: credentials,
          request: anyNamed('request'),
        ),
      ).thenAnswer((_) => Future.value(mockResponse));

      // When
      InternalException? exception;
      try {
        final dto = GetRemoteBundleDto(
          credentials: credentials,
          appVersion: '1',
          translationVersion: 1,
          preRelease: true,
        );
        await remoteRepo.getBundle(
          getRemoteBundleDto: dto,
        );
      } on InternalException catch (e) {
        exception = e;
      }

      // Then
      expect(exception, isNotNull);
      expect(exception!.code, equals(InternalException.bundleEmptyError));
    });

    test('wrong bundle format', () async {
      // Given
      final zipFile = File('test/assets/bundle-wrong_format.zip');
      final mockResponse = BundleResponse(
        bundle: ZipDecoder().decodeBytes(zipFile.readAsBytesSync()),
        version: 15,
      );
      when(
        otaApiMock.getBundle(
          credentials: credentials,
          request: anyNamed('request'),
        ),
      ).thenAnswer((_) => Future.value(mockResponse));

      // When
      InternalException? exception;
      try {
        final dto = GetRemoteBundleDto(
          credentials: credentials,
          appVersion: '1',
          translationVersion: 1,
          preRelease: true,
        );
        await remoteRepo.getBundle(
          getRemoteBundleDto: dto,
        );
      } on InternalException catch (e) {
        exception = e;
      }

      // Then
      expect(exception, isNotNull);
      expect(exception!.code, equals(InternalException.bundleFormatError));
    });

    test('success', () async {
      // Given
      final zipFile = File('test/assets/bundle-correct.zip');
      final mockResponse = BundleResponse(
        bundle: ZipDecoder().decodeBytes(zipFile.readAsBytesSync()),
        version: 15,
      );
      when(
        otaApiMock.getBundle(
          credentials: credentials,
          request: anyNamed('request'),
        ),
      ).thenAnswer((_) => Future.value(mockResponse));

      // When
      final dto = GetRemoteBundleDto(
        credentials: credentials,
        appVersion: '1',
        translationVersion: 1,
        preRelease: true,
      );
      final result = await remoteRepo.getBundle(
        getRemoteBundleDto: dto,
      );

      // Then
      expect(result!.projectId, equals(credentials.projectId));
      expect(result.appVersion, equals(dto.appVersion));
      expect(result.translationVersion, equals(mockResponse.version));
      expect(result.languageBundles.length, equals(3));

      for (final element in result.languageBundles) {
        expect(element.translations.length, equals(1));

        String value = '';
        switch (element.locale) {
          case 'en':
            value = 'hello world';
            break;
          case 'es':
            value = 'hola mundo';
            break;
          case 'lv':
            value = 'sveika pasaule';
            break;
          default:
            throw Exception('Unexpected locale: ${element.locale}');
        }

        expect(
          element.translations['hello_world']!.getTranslation({}),
          equals(value),
        );
      }
    });
  });
}
